==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus.md <==
# AwsIoTGreengrassComponentNucleus


```text
aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus
```

```text
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')
```



| Illustration | AwsIoTGreengrassComponentNucleus | AwsIoTGreengrassComponentNucleusCard | AwsIoTGreengrassComponentNucleusGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus.png) | ![illustration for AwsIoTGreengrassComponentNucleus](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus.Local.png) | ![illustration for AwsIoTGreengrassComponentNucleusCard](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleusCard.Local.png) | ![illustration for AwsIoTGreengrassComponentNucleusGroup](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleusGroup.Local.png) |




## AwsIoTGreengrassComponentNucleus

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleus
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleus('AwsIoTGreengrassComponentNucleus', 'Aws Io T Greengrass Component Nucleus', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleus
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleus('AwsIoTGreengrassComponentNucleus', 'Aws Io T Greengrass Component Nucleus', 'an optional tech label')
@enduml
```

## AwsIoTGreengrassComponentNucleusCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusCard('AwsIoTGreengrassComponentNucleusCard', 'Aws Io T Greengrass Component Nucleus Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusCard('AwsIoTGreengrassComponentNucleusCard', 'Aws Io T Greengrass Component Nucleus Card', 'an optional description')
@enduml
```

## AwsIoTGreengrassComponentNucleusGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusGroup('AwsIoTGreengrassComponentNucleusGroup', 'Aws Io T Greengrass Component Nucleus Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusGroup('AwsIoTGreengrassComponentNucleusGroup', 'Aws Io T Greengrass Component Nucleus Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus.md <==
# AwsIoTGreengrassComponentNucleus


```text
aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus
```

```text
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')
```



| Illustration | AwsIoTGreengrassComponentNucleus | AwsIoTGreengrassComponentNucleusCard | AwsIoTGreengrassComponentNucleusGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus.png) | ![illustration for AwsIoTGreengrassComponentNucleus](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus.Local.png) | ![illustration for AwsIoTGreengrassComponentNucleusCard](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleusCard.Local.png) | ![illustration for AwsIoTGreengrassComponentNucleusGroup](../../../aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleusGroup.Local.png) |




## AwsIoTGreengrassComponentNucleus

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleus
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleus('AwsIoTGreengrassComponentNucleus', 'Aws Io T Greengrass Component Nucleus', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleus
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleus('AwsIoTGreengrassComponentNucleus', 'Aws Io T Greengrass Component Nucleus', 'an optional tech label')
@enduml
```

## AwsIoTGreengrassComponentNucleusCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusCard('AwsIoTGreengrassComponentNucleusCard', 'Aws Io T Greengrass Component Nucleus Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusCard
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusCard('AwsIoTGreengrassComponentNucleusCard', 'Aws Io T Greengrass Component Nucleus Card', 'an optional description')
@enduml
```

## AwsIoTGreengrassComponentNucleusGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusGroup('AwsIoTGreengrassComponentNucleusGroup', 'Aws Io T Greengrass Component Nucleus Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTGreengrassComponentNucleusGroup
include('aws-20210730/Resource/LoT/AwsIoTGreengrassComponentNucleus')

' renders the element
AwsIoTGreengrassComponentNucleusGroup('AwsIoTGreengrassComponentNucleusGroup', 'Aws Io T Greengrass Component Nucleus Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
